magneticalc.GUI.GUI

# ``magneticalc`.`GUI`.`GUI``

class documentation

`class GUI(QMainWindow):`

Constructor: `GUI()`

View In Hierarchy

GUI class.

Method | `__init__` | Initializes the GUI.
Method | `cleanup` | Perform clean-up upon quitting the application.
Method | `closeEvent` | Gets called when the window is closed (programmatically through close() or manually)
Method | `interrupt_calculation` | Kills any running calculation.
Method | `keyPressEvent` | Handles key press event.
Method | `on_calculation_exited` | This is called after calculation thread has exited.
Method | `re_wrapper` | Simple wrapper that decides between recalculation or redraw.
Method | `recalculate` | Recalculates the model.
Method | `redraw` | Redraws the scene.
Method | `reload` | Reloads the GUI.
Class Variable | `calculation_exited` | Undocumented
Class Variable | `calculation_status` | Undocumented
Class Variable | `invalidate_statusbar` | Undocumented
Class Variable | `MinimumWindowSize` | Undocumented
Instance Variable | `calculation_start_time` | Undocumented
Instance Variable | `calculation_thread` | Undocumented
Instance Variable | `exiting` | Undocumented
Instance Variable | `initializing` | Undocumented
Instance Variable | `menu` | Undocumented
Instance Variable | `model` | Undocumented
Instance Variable | `project` | Undocumented
Instance Variable | `sidebar_left` | Undocumented
Instance Variable | `sidebar_right` | Undocumented
Instance Variable | `splitter` | Undocumented
Instance Variable | `statusbar` | Undocumented
Instance Variable | `user_locale` | Undocumented
Instance Variable | `vispy_canvas` | Undocumented

def __init__(self):

Initializes the GUI.

def cleanup(self):

Perform clean-up upon quitting the application.

def closeEvent(self, event: `QCloseEvent`):

Gets called when the window is closed (programmatically through close() or manually)

Parameters
event: `QCloseEvent` | Close event

def interrupt_calculation(self):

Kills any running calculation.

def keyPressEvent(self, event: `QKeyEvent`):

Handles key press event.

Parameters
event: `QKeyEvent` | Key press event

def on_calculation_exited(self, success: `bool`):

This is called after calculation thread has exited.

Parameters
success: `bool` | True if calculation was successful, False otherwise

def re_wrapper(self):

Simple wrapper that decides between recalculation or redraw.

def recalculate(self):

Recalculates the model.

def redraw(self):

Redraws the scene.

def reload(self):

Reloads the GUI.

calculation_exited =

Undocumented

calculation_status =

Undocumented

invalidate_statusbar =

Undocumented

MinimumWindowSize: `tuple[int, ...]` =

Undocumented

calculation_start_time =

Undocumented

calculation_thread =

Undocumented

exiting: `bool` =

Undocumented

initializing: `bool` =

Undocumented

menu =

Undocumented

model =

Undocumented

project =

Undocumented

sidebar_left =

Undocumented

sidebar_right =

Undocumented

splitter =

Undocumented

statusbar =

Undocumented

user_locale =

Undocumented

vispy_canvas =

Undocumented